#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              2.2.0.0
visibility:           public
id:                   lsp-2.2.0.0-62EvDy2Nc6JD5v5vZC9bSk
key:                  lsp-2.2.0.0-62EvDy2Nc6JD5v5vZC9bSk
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  5b1ffc5d5af25126035fe587b2328d27
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Logging,
    Language.LSP.Protocol.Capabilities from lsp-types-2.0.2.0-2flfgFvwnWPAWn5iHER2lx:Language.LSP.Protocol.Capabilities,
    Language.LSP.Protocol.Lens from lsp-types-2.0.2.0-2flfgFvwnWPAWn5iHER2lx:Language.LSP.Protocol.Lens,
    Language.LSP.Protocol.Message from lsp-types-2.0.2.0-2flfgFvwnWPAWn5iHER2lx:Language.LSP.Protocol.Message,
    Language.LSP.Protocol.Types from lsp-types-2.0.2.0-2flfgFvwnWPAWn5iHER2lx:Language.LSP.Protocol.Types,
    Language.LSP.Server, Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Control Language.LSP.Server.Core
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lsp-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp
hs-libraries:         HSlsp-2.2.0.0-62EvDy2Nc6JD5v5vZC9bSk
depends:
    aeson-2.2.2.0-HX3VmpxSu7MBeXlY03a2B0
    async-2.2.6-6oBfo7va0Nh7ISraaAL0Gg
    attoparsec-0.14.4-5ZTCKiuMNMIGB4CMz6Pozo base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-BA3nx5gcNuiATplO11CYNb
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-J2hh6EbI83E8iCoykKa5KL
    lens-5.3.4-1IL9mxUdyyZ2Td3b3fp10G
    lens-aeson-1.2.3-2L3IMbgxyk3HzNxitqHDf2
    lsp-types-2.0.2.0-2flfgFvwnWPAWn5iHER2lx mtl-2.3.1
    prettyprinter-1.7.1-1xxpbQWBfCkKy2RpQWmuRC
    random-1.2.1.3-5RWjRNGMcAI4pn7QxDBoxf
    row-types-1.0.1.2-4t1oGU6lVRSIw9AnA66uBt
    sorted-list-0.2.3.1-7cafC68p20S9YCdi7hF1Xg stm-2.5.1.0
    temporary-1.3-8J7tb17AXGL7EVC1xEc9YW text-2.0.2
    text-rope-0.3-Et3zzhmV9C052PCXSjs9WW transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-F8uKhGV3AlWbjcYkQjkcw
    uuid-1.3.16.1-DhWV9fEoepV648QL3EtyBy

haddock-interfaces:   /usr/share/doc/haskell-lsp/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

